setSingularDeviceID static method

Future<void> setSingularDeviceID(
  1. String singularDeviceID
)

Subscriber attribute associated with the Singular Device ID (SDID) for the user. Required for the RevenueCat Singular integration when using Singular's Event Endpoint V2.

The SDID is generated by the Singular SDK and cannot be collected by collectDeviceIdentifiers, so it has to be forwarded by the app.

singularDeviceID Empty String or null will delete the subscriber attribute.

Implementation

static Future<void> setSingularDeviceID(String singularDeviceID) =>
    _channel.invokeMethod(
      'setSingularDeviceID',
      {'singularDeviceID': singularDeviceID},
    );