SubscriptionStatus class
Constructors
- SubscriptionStatus({required bool isActive, required bool willRenew, String? expirationDate, bool isSandbox = false})
-
const
- SubscriptionStatus.notSubscribed()
-
factory
Properties
- expirationDate → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
final
- isCancelledButActive → bool
-
no setter
- isExpired → bool
-
no setter
- isSandbox → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- willRenew → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited