ownershipType property

OwnershipType ownershipType
final

Use this property to determine whether a purchase was made by the current user or shared to them by a family member. This can be useful for onboarding users who have had an entitlement shared with them, but might not be entirely aware of the benefits they now have.

Implementation

final OwnershipType ownershipType;