PurchasesAdTracker class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackAdDisplayed(
AdDisplayedData data) → Future< void> -
trackAdFailedToLoad(
AdFailedToLoadData data) → Future< void> -
trackAdLoaded(
AdLoadedData data) → Future< void> -
trackAdOpened(
AdOpenedData data) → Future< void> -
trackAdRevenue(
AdRevenueData data) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited